# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from foxtail_trainer_api.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from foxtail_trainer_api.model.add_or_update_model_hyperparameter import AddOrUpdateModelHyperparameter
from foxtail_trainer_api.model.add_or_update_model_hyperparameter_in_job import AddOrUpdateModelHyperparameterInJob
from foxtail_trainer_api.model.aggregated_metric_report_dto import AggregatedMetricReportDto
from foxtail_trainer_api.model.create_custom_metric_dto import CreateCustomMetricDto
from foxtail_trainer_api.model.create_data_sets_sizes_dto import CreateDataSetsSizesDto
from foxtail_trainer_api.model.create_job_command import CreateJobCommand
from foxtail_trainer_api.model.create_ml_model_dto import CreateMLModelDto
from foxtail_trainer_api.model.create_ml_models_command import CreateMLModelsCommand
from foxtail_trainer_api.model.create_metric_dto import CreateMetricDto
from foxtail_trainer_api.model.create_model_hyperparameter_dto import CreateModelHyperparameterDto
from foxtail_trainer_api.model.create_prediction_task_command import CreatePredictionTaskCommand
from foxtail_trainer_api.model.create_training_config_dto import CreateTrainingConfigDto
from foxtail_trainer_api.model.create_training_history_dto import CreateTrainingHistoryDto
from foxtail_trainer_api.model.create_training_result_command import CreateTrainingResultCommand
from foxtail_trainer_api.model.create_training_result_dto import CreateTrainingResultDto
from foxtail_trainer_api.model.created_job_dto import CreatedJobDto
from foxtail_trainer_api.model.created_ml_models_dto import CreatedMLModelsDto
from foxtail_trainer_api.model.created_prediction_task_dto import CreatedPredictionTaskDto
from foxtail_trainer_api.model.custom_metric_dto import CustomMetricDto
from foxtail_trainer_api.model.custom_model_hyperparameter_dto import CustomModelHyperparameterDto
from foxtail_trainer_api.model.custom_model_hyperparameter_with_model_dto import CustomModelHyperparameterWithModelDto
from foxtail_trainer_api.model.data_set_chunk_basic_dto import DataSetChunkBasicDto
from foxtail_trainer_api.model.data_set_chunk_dto import DataSetChunkDto
from foxtail_trainer_api.model.data_set_chunks_list_dto import DataSetChunksListDto
from foxtail_trainer_api.model.data_sets_sizes_dto import DataSetsSizesDto
from foxtail_trainer_api.model.deleted_ml_models_dto import DeletedMLModelsDto
from foxtail_trainer_api.model.get_worker_dto import GetWorkerDto
from foxtail_trainer_api.model.job_basic_dto import JobBasicDto
from foxtail_trainer_api.model.job_dto import JobDto
from foxtail_trainer_api.model.job_metric_report_dto import JobMetricReportDto
from foxtail_trainer_api.model.job_training_config_dto import JobTrainingConfigDto
from foxtail_trainer_api.model.jobs_list_dto import JobsListDto
from foxtail_trainer_api.model.log_dto import LogDto
from foxtail_trainer_api.model.log_level import LogLevel
from foxtail_trainer_api.model.ml_model_dto import MLModelDto
from foxtail_trainer_api.model.ml_model_metric_report_dto import MLModelMetricReportDto
from foxtail_trainer_api.model.ml_models_guids_list_dto import MLModelsGuidsListDto
from foxtail_trainer_api.model.ml_models_metric_list_report_dto import MLModelsMetricListReportDto
from foxtail_trainer_api.model.ml_models_status_count_report_dto import MLModelsStatusCountReportDto
from foxtail_trainer_api.model.ml_models_status_counts_list_report_dto import MLModelsStatusCountsListReportDto
from foxtail_trainer_api.model.ml_models_status_list_report_dto import MLModelsStatusListReportDto
from foxtail_trainer_api.model.ml_models_status_report_dto import MLModelsStatusReportDto
from foxtail_trainer_api.model.ml_models_url_list_report_dto import MLModelsUrlListReportDto
from foxtail_trainer_api.model.ml_models_url_report_dto import MLModelsUrlReportDto
from foxtail_trainer_api.model.ml_models_with_training_results_dto import MLModelsWithTrainingResultsDto
from foxtail_trainer_api.model.metric_dto import MetricDto
from foxtail_trainer_api.model.metric_dto_with_model import MetricDtoWithModel
from foxtail_trainer_api.model.metric_report_dto import MetricReportDto
from foxtail_trainer_api.model.metric_type import MetricType
from foxtail_trainer_api.model.model_hyperparameter_dto import ModelHyperparameterDto
from foxtail_trainer_api.model.model_status import ModelStatus
from foxtail_trainer_api.model.model_type import ModelType
from foxtail_trainer_api.model.override_model_hyperparameter_command import OverrideModelHyperparameterCommand
from foxtail_trainer_api.model.prediction_input_model_dto import PredictionInputModelDto
from foxtail_trainer_api.model.prediction_model_task_dto import PredictionModelTaskDto
from foxtail_trainer_api.model.prediction_status import PredictionStatus
from foxtail_trainer_api.model.prediction_task_dto import PredictionTaskDto
from foxtail_trainer_api.model.problem_type import ProblemType
from foxtail_trainer_api.model.run_job_command import RunJobCommand
from foxtail_trainer_api.model.run_prediction_task_command import RunPredictionTaskCommand
from foxtail_trainer_api.model.runed_job_dto import RunedJobDto
from foxtail_trainer_api.model.runed_prediction_task_dto import RunedPredictionTaskDto
from foxtail_trainer_api.model.submit_prediction_command import SubmitPredictionCommand
from foxtail_trainer_api.model.training_config_dto import TrainingConfigDto
from foxtail_trainer_api.model.training_history_dto import TrainingHistoryDto
from foxtail_trainer_api.model.training_result_dto import TrainingResultDto
from foxtail_trainer_api.model.training_result_with_model_dto import TrainingResultWithModelDto
from foxtail_trainer_api.model.training_time_report_dto import TrainingTimeReportDto
from foxtail_trainer_api.model.update_data_set_chunk_status_command import UpdateDataSetChunkStatusCommand
from foxtail_trainer_api.model.update_data_sets_sizes_dto import UpdateDataSetsSizesDto
from foxtail_trainer_api.model.update_job_training_config_command import UpdateJobTrainingConfigCommand
from foxtail_trainer_api.model.update_ml_model_definition_dto import UpdateMLModelDefinitionDto
from foxtail_trainer_api.model.update_ml_models_definition_command import UpdateMLModelsDefinitionCommand
from foxtail_trainer_api.model.update_ml_models_status_command import UpdateMLModelsStatusCommand
from foxtail_trainer_api.model.worker_ml_model_dto import WorkerMLModelDto
